pilas.motores.motor_qt.Texto

Package pilas :: Package motores :: Module motor_qt :: Class Texto |
[hide private]
[frames] | no frames]

# Class Texto

source code

    object --+
             |
        Imagen --+
                 |
                Texto

Instance Methods | [hide private]
__init__(self, texto, magnitud, motor, vertical=False, fuente=None) x.__init__(...) initializes x; see help(type(x)) for signature | source code
_dibujar_pixmap(self, painter, dx, dy) | source code
ancho(self) | source code
alto(self) | source code
Inherited from `Imagen`: `__str__`, `avanzar`, `cargar_jpeg`, `centro`, `dibujar` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Methods | [hide private]
cargar_fuente_desde_cache(kclass, fuente_como_ruta) Carga o convierte una fuente para ser utilizada dentro del motor. | source code

Class Variables | [hide private]
| CACHE_FUENTES = `{}`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, texto, magnitud, motor, vertical=False, fuente=None) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### _dibujar_pixmap(self, painter, dx, dy) | source code
Overrides: Imagen._dibujar_pixmap

### cargar_fuente_desde_cache(kclass, fuente_como_ruta) Class Method | source code
Carga o convierte una fuente para ser utilizada dentro del motor. Permite a los usuarios referirse a las fuentes como ruta a archivos, sin tener que preocuparse por el font-family. :param fuente_como_ruta: Ruta al archivo TTF que se quiere utilizar. Ejemplo:
    >>> Texto.cargar_fuente_desde_cache('myttffile.ttf')
    'Visitor TTF1'

### ancho(self) | source code
Overrides: Imagen.ancho

### alto(self) | source code
Overrides: Imagen.alto